@@ -100,6 +100,7 @@ struct PkBackendJobPrivate
 	gboolean		 allow_cancel;
 	gboolean		 background;
 	gboolean		 interactive;
+	gboolean		 details_with_deps_size;
 	gboolean		 locked;
 	GHashTable		*emitted;
 	PkErrorEnum		 last_error_code;
@@ -482,6 +483,20 @@ pk_backend_job_set_interactive (PkBackendJob *job, gboolean interactive)
 	job->priv->interactive = interactive;
 }
 
+gboolean
+pk_backend_job_get_details_with_deps_size (PkBackendJob *job)
+{
+	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), FALSE);
+	return job->priv->details_with_deps_size;
+}
+
+void
+pk_backend_job_set_details_with_deps_size (PkBackendJob *job, gboolean details_with_deps_size)
+{
+	g_return_if_fail (PK_IS_BACKEND_JOB (job));
+	job->priv->details_with_deps_size = details_with_deps_size;
+}
+
 PkRoleEnum
 pk_backend_job_get_role (PkBackendJob *job)
 {
